@@ -20,15 +20,11 @@ if [[ ! $os == "Linux" ]] && [[ ! $os == "Darwin" ]]; then
 fi
 
 install_requirements(){
-    # TODO: if not [automake --version]
     if [ "$os" == "Linux" ]; then
         if [ "$(grep -Ei 'debian|buntu|mint' /etc/*release)" ]; then
-            $sudo apt-get update
-            $sudo apt-get install -y build-essential curl python3-devel libmecab-dev git
-            $sudo apt-key adv --keyserver keyserver.ubuntu.com --recv-keys A4B469963BF863CC
+            $sudo apt-get update && $sudo apt-get install build-essential curl python3-devel libmecab-dev git -y && $sudo apt-key adv --keyserver keyserver.ubuntu.com --recv-keys A4B469963BF863CC
         elif [ "$(grep -Ei 'fedora|redhat' /etc/*release)" ]; then
-            $sudo yum groupinstall -y 'Development Tools' 'Development Libraries'
-            $sudo yum install -y curl python3-devel  git
+            $sudo yum groupinstall 'Development Tools' 'Development Libraries' -y && $sudo yum install curl python3-devel git -y
         fi
     elif [ "$os" == "Darwin" ]; then
         if [[ $(command -v brew) == "" ]]; then
